==> vtk6-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkImageQuantizeRGBToIndex.java <==
// java wrapper for vtkImageQuantizeRGBToIndex object
//

package vtk;
import vtk.*;

public class vtkImageQuantizeRGBToIndex extends vtkImageAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetNumberOfColors_2(int id0);
  public void SetNumberOfColors(int id0)
    { SetNumberOfColors_2(id0); }

  private native int GetNumberOfColorsMinValue_3();
  public int GetNumberOfColorsMinValue()
    { return GetNumberOfColorsMinValue_3(); }

  private native int GetNumberOfColorsMaxValue_4();
  public int GetNumberOfColorsMaxValue()
    { return GetNumberOfColorsMaxValue_4(); }

  private native int GetNumberOfColors_5();
  public int GetNumberOfColors()
    { return GetNumberOfColors_5(); }

  private native long GetLookupTable_6();
  public vtkLookupTable GetLookupTable() {
    long temp = GetLookupTable_6();

    if (temp == 0) return null;
    return (vtkLookupTable)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native double GetInitializeExecuteTime_7();
  public double GetInitializeExecuteTime()
    { return GetInitializeExecuteTime_7(); }

  private native double GetBuildTreeExecuteTime_8();
  public double GetBuildTreeExecuteTime()
    { return GetBuildTreeExecuteTime_8(); }

  private native double GetLookupIndexExecuteTime_9();
  public double GetLookupIndexExecuteTime()
    { return GetLookupIndexExecuteTime_9(); }

  private native int GetInputType_10();
  public int GetInputType()
    { return GetInputType_10(); }

  private native void SetInitializeExecuteTime_11(double id0);
  public void SetInitializeExecuteTime(double id0)
    { SetInitializeExecuteTime_11(id0); }

  private native void SetBuildTreeExecuteTime_12(double id0);
  public void SetBuildTreeExecuteTime(double id0)
    { SetBuildTreeExecuteTime_12(id0); }

  private native void SetLookupIndexExecuteTime_13(double id0);
  public void SetLookupIndexExecuteTime(double id0)
    { SetLookupIndexExecuteTime_13(id0); }

  public vtkImageQuantizeRGBToIndex() { super(); }

  public vtkImageQuantizeRGBToIndex(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.0.1-3-aarch64.pkg.tar.xz: vtk/vtkImageQuantizeRGBToIndex.java <==
// java wrapper for vtkImageQuantizeRGBToIndex object
//

package vtk;
import vtk.*;

public class vtkImageQuantizeRGBToIndex extends vtkImageAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetNumberOfColors_2(int id0);
  public void SetNumberOfColors(int id0)
    { SetNumberOfColors_2(id0); }

  private native int GetNumberOfColorsMinValue_3();
  public int GetNumberOfColorsMinValue()
    { return GetNumberOfColorsMinValue_3(); }

  private native int GetNumberOfColorsMaxValue_4();
  public int GetNumberOfColorsMaxValue()
    { return GetNumberOfColorsMaxValue_4(); }

  private native int GetNumberOfColors_5();
  public int GetNumberOfColors()
    { return GetNumberOfColors_5(); }

  private native long GetLookupTable_6();
  public vtkLookupTable GetLookupTable() {
    long temp = GetLookupTable_6();

    if (temp == 0) return null;
    return (vtkLookupTable)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native double GetInitializeExecuteTime_7();
  public double GetInitializeExecuteTime()
    { return GetInitializeExecuteTime_7(); }

  private native double GetBuildTreeExecuteTime_8();
  public double GetBuildTreeExecuteTime()
    { return GetBuildTreeExecuteTime_8(); }

  private native double GetLookupIndexExecuteTime_9();
  public double GetLookupIndexExecuteTime()
    { return GetLookupIndexExecuteTime_9(); }

  private native int GetInputType_10();
  public int GetInputType()
    { return GetInputType_10(); }

  private native void SetInitializeExecuteTime_11(double id0);
  public void SetInitializeExecuteTime(double id0)
    { SetInitializeExecuteTime_11(id0); }

  private native void SetBuildTreeExecuteTime_12(double id0);
  public void SetBuildTreeExecuteTime(double id0)
    { SetBuildTreeExecuteTime_12(id0); }

  private native void SetLookupIndexExecuteTime_13(double id0);
  public void SetLookupIndexExecuteTime(double id0)
    { SetLookupIndexExecuteTime_13(id0); }

  public vtkImageQuantizeRGBToIndex() { super(); }

  public vtkImageQuantizeRGBToIndex(long id) { super(id); }
  public native long   VTKInit();

}
